@@ -7,8 +7,8 @@ test_that("wb_workbook() is a wrapper", {
   ts <- Sys.time()
   expect_identical(formals(wbWorkbook$public_methods$initialize), formals(wb_workbook))
   expect_identical(
-    wbWorkbook$new(datetimeCreated = ts),
-    wb_workbook(datetimeCreated = ts)
+    wbWorkbook$new(datetime_created = ts),
+    wb_workbook(datetime_created = ts)
   )
 })
 
@@ -59,7 +59,7 @@ test_that("wb_save() is a wrapper", {
 
 test_that("wb_merge_cells(), wb_unmerge_cells() are wrappers", {
   wb <- wb_workbook()$add_worksheet("sheet")
-  params <- list(sheet = "sheet", rows = 1:2, cols = 2)
+  params <- list(sheet = "sheet", dims = wb_dims(rows = 1:2, cols = 2))
   expect_wrapper("merge_cells", wb = wb, params = params)
   expect_wrapper("unmerge_cells", wb = wb, params = params)
 })
@@ -183,7 +183,7 @@ test_that("wb_page_setup() is a wrapper", {
 # wb_set_base_font() ----------------------------------------------------------
 
 test_that("wb_set_base_font() is a wrapper", {
-  params <- list(fontColour = "red", fontSize = 20)
+  params <- list(font_colour = "red", font_size = 20)
   expect_wrapper("set_base_font", params = params)
 })
 
@@ -212,7 +212,7 @@ test_that("wb_get_bookview() is a wrapper", {
 })
 
 test_that("wb_set_bookview() is a wrapper", {
-  params <- list(activeTab = "1")
+  params <- list(active_tab = "1")
   expect_wrapper("set_bookview", params = params)
 })
 
@@ -292,7 +292,7 @@ test_that("wb_get_tables(), wb_remove_tables() are wrappers", {
   wb <- wb_workbook()
   wb$add_worksheet(sheet = "Sheet 1")
   wb$add_data_table(sheet = "Sheet 1", x = iris)
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
   expect_wrapper("get_tables", wb = wb, params = list(sheet = 1))
   expect_wrapper("remove_tables", wb = wb, params = list(sheet = 1, table = "mtcars"))
 })
@@ -457,7 +457,7 @@ test_that("wb_update_table() is a wrapper", {
 
 test_that("wb_copy_cells() is a wrapper", {
   wb <- wb_workbook()$add_worksheet(1)$add_data(x = "1")
-  dat <- wb_data(wb, 1, dims = "A1", colNames = FALSE)
+  dat <- wb_data(wb, 1, dims = "A1", col_names = FALSE)
   expect_wrapper("copy_cells",     wb = wb, params = list(sheet = 1, data = dat, dims = "B1"))
 })
 
@@ -465,7 +465,7 @@ test_that("wb_copy_cells() is a wrapper", {
 
 test_that("wb_add_comment() is a wrapper", {
 
-  c1 <- create_comment(text = "this is a comment", author = "")
+  c1 <- wb_comment(text = "this is a comment", author = "")
 
   wb <- wb_workbook()$add_worksheet()
   expect_wrapper(
@@ -503,7 +503,7 @@ test_that("wb_get_comment() is a wrapper", {
 
 test_that("wb_remove_comment() is a wrapper", {
 
-  c1 <- create_comment(text = "this is a comment", author = "")
+  c1 <- wb_comment(text = "this is a comment", author = "")
 
   wb <- wb_workbook()$
     add_worksheet()$
@@ -575,7 +575,7 @@ test_that("wb_add_form_control() is a wrapper", {
 
 test_that("wb_add_conditional_formatting() is a wrapper", {
   wb <- wb_workbook()$add_worksheet(1)
-  params <- list(sheet = 1, cols = 1, rows = 1, type = "topN")
+  params <- list(sheet = 1, dims = wb_dims(cols = 1, rows = 1), type = "topN")
   expect_wrapper(
     "add_conditional_formatting",
     wb = wb,
@@ -726,7 +726,7 @@ test_that("wb_set_sheetview() is a wrapper", {
   expect_wrapper(
     "set_sheetview",
     wb = wb,
-    params = list(rightToLeft = TRUE)
+    params = list(right_to_left = TRUE)
   )
 })
 
